@@ -9,12 +9,13 @@
 
 # The code is copied from skinnywms, and we should combile later
 
+import datetime
 from contextlib import closing
 from itertools import product
 
-import xarray as xr
-import datetime
 import numpy as np
+import xarray as xr
+
 from . import Reader
 
 
@@ -183,8 +184,8 @@ class NetCDFReader(Reader):
 
         for name in ds.data_vars:
             v = ds[name]
-            skip.update([c for c in getattr(v, "coordinates", "").split(" ")])
-            skip.update([c for c in getattr(v, "bounds", "").split(" ")])
+            skip.update(getattr(v, "coordinates", "").split(" "))
+            skip.update(getattr(v, "bounds", "").split(" "))
 
         for name in ds.data_vars:
 
@@ -255,11 +256,9 @@ class NetCDFReader(Reader):
                 fields.append(NetCDFField(self.path, ds, name, slices))
 
         if not fields:
-            raise Exception("NetCDFReader no 2D fields found in %s", self.path)
+            raise Exception("NetCDFReader no 2D fields found in %s" % (self.path,))
 
         return fields
 
     def to_xarray(self):
-        import xarray as xr
-
         return xr.open_dataset(self.path)
